[PATCH 1/2] score: Rename Priority_bit_map_Control

Sebastian Huber sebastian.huber at embedded-brains.de
Tue Apr 1 12:36:13 UTC 2014


Rename Priority_bit_map_Control in Priority_bit_map_Word.
---
 cpukit/score/cpu/arm/rtems/score/types.h           |    2 +-
 cpukit/score/cpu/avr/rtems/score/cpu.h             |    2 +-
 cpukit/score/cpu/avr/rtems/score/types.h           |    2 +-
 cpukit/score/cpu/bfin/rtems/score/cpu.h            |    2 +-
 cpukit/score/cpu/bfin/rtems/score/types.h          |    2 +-
 cpukit/score/cpu/h8300/rtems/score/cpu.h           |    2 +-
 cpukit/score/cpu/h8300/rtems/score/types.h         |    2 +-
 cpukit/score/cpu/i386/rtems/score/types.h          |    2 +-
 cpukit/score/cpu/lm32/rtems/score/cpu.h            |    2 +-
 cpukit/score/cpu/lm32/rtems/score/types.h          |    2 +-
 cpukit/score/cpu/m32c/rtems/score/cpu.h            |    2 +-
 cpukit/score/cpu/m32c/rtems/score/types.h          |    2 +-
 cpukit/score/cpu/m32r/rtems/score/cpu.h            |    2 +-
 cpukit/score/cpu/m32r/rtems/score/types.h          |    2 +-
 cpukit/score/cpu/m68k/rtems/score/types.h          |    2 +-
 cpukit/score/cpu/mips/rtems/score/cpu.h            |    2 +-
 cpukit/score/cpu/mips/rtems/score/types.h          |    2 +-
 cpukit/score/cpu/moxie/rtems/score/types.h         |    2 +-
 cpukit/score/cpu/nios2/rtems/score/types.h         |    2 +-
 cpukit/score/cpu/no_cpu/rtems/score/cpu.h          |    2 +-
 cpukit/score/cpu/no_cpu/rtems/score/types.h        |    2 +-
 cpukit/score/cpu/powerpc/rtems/score/cpu.h         |    2 +-
 cpukit/score/cpu/powerpc/rtems/score/types.h       |    2 +-
 cpukit/score/cpu/sh/rtems/score/cpu.h              |    2 +-
 cpukit/score/cpu/sh/rtems/score/types.h            |    2 +-
 cpukit/score/cpu/sparc/rtems/score/types.h         |    2 +-
 cpukit/score/cpu/sparc64/rtems/score/types.h       |    2 +-
 cpukit/score/cpu/v850/rtems/score/cpu.h            |    2 +-
 cpukit/score/cpu/v850/rtems/score/types.h          |    2 +-
 cpukit/score/include/rtems/score/prioritybitmap.h  |   12 +++---
 .../score/include/rtems/score/prioritybitmapimpl.h |   42 ++++++++++----------
 cpukit/score/src/prioritybitmap.c                  |    4 +-
 32 files changed, 58 insertions(+), 58 deletions(-)

diff --git a/cpukit/score/cpu/arm/rtems/score/types.h b/cpukit/score/cpu/arm/rtems/score/types.h
index 1b5cfba..6910e18 100644
--- a/cpukit/score/cpu/arm/rtems/score/types.h
+++ b/cpukit/score/cpu/arm/rtems/score/types.h
@@ -37,7 +37,7 @@ extern "C" {
  *  This section defines the basic types for this processor.
  */
 
-typedef uint16_t         Priority_bit_map_Control;
+typedef uint16_t         Priority_bit_map_Word;
 
 /** @} */
 
diff --git a/cpukit/score/cpu/avr/rtems/score/cpu.h b/cpukit/score/cpu/avr/rtems/score/cpu.h
index f7753a2..70a0ddb 100644
--- a/cpukit/score/cpu/avr/rtems/score/cpu.h
+++ b/cpukit/score/cpu/avr/rtems/score/cpu.h
@@ -824,7 +824,7 @@ uint32_t   _CPU_ISR_Get_level( void );
 
 /*
  *  This routine sets _output to the bit number of the first bit
- *  set in _value.  _value is of CPU dependent type Priority_bit_map_Control.
+ *  set in _value.  _value is of CPU dependent type Priority_bit_map_Word.
  *  This type may be either 16 or 32 bits wide although only the 16
  *  least significant bits will be used.
  *
diff --git a/cpukit/score/cpu/avr/rtems/score/types.h b/cpukit/score/cpu/avr/rtems/score/types.h
index ec769c4..0de6ba2 100644
--- a/cpukit/score/cpu/avr/rtems/score/types.h
+++ b/cpukit/score/cpu/avr/rtems/score/types.h
@@ -31,7 +31,7 @@ extern "C" {
  *  This section defines the basic types for this processor.
  */
 
-typedef uint16_t     Priority_bit_map_Control;
+typedef uint16_t     Priority_bit_map_Word;
 typedef void avr_isr;
 typedef void ( *avr_isr_entry )( void );
 
diff --git a/cpukit/score/cpu/bfin/rtems/score/cpu.h b/cpukit/score/cpu/bfin/rtems/score/cpu.h
index e26d1ac..306e4eb 100644
--- a/cpukit/score/cpu/bfin/rtems/score/cpu.h
+++ b/cpukit/score/cpu/bfin/rtems/score/cpu.h
@@ -953,7 +953,7 @@ void _CPU_Context_Initialize(
 /**
  * This routine sets @a _output to the bit number of the first bit
  * set in @a _value.  @a _value is of CPU dependent type
- * @a Priority_bit_map_Control.  This type may be either 16 or 32 bits
+ * @a Priority_bit_map_Word.  This type may be either 16 or 32 bits
  * wide although only the 16 least significant bits will be used.
  *
  * There are a number of variables in using a "find first bit" type
diff --git a/cpukit/score/cpu/bfin/rtems/score/types.h b/cpukit/score/cpu/bfin/rtems/score/types.h
index 8eeb5ef..ff120b9 100644
--- a/cpukit/score/cpu/bfin/rtems/score/types.h
+++ b/cpukit/score/cpu/bfin/rtems/score/types.h
@@ -32,7 +32,7 @@ extern "C" {
  */
 
 /** This defines the type for a priority bit map entry. */
-typedef uint16_t Priority_bit_map_Control;
+typedef uint16_t Priority_bit_map_Word;
 
 /** This defines the return type for an ISR entry point. */
 typedef void blackfin_isr;
diff --git a/cpukit/score/cpu/h8300/rtems/score/cpu.h b/cpukit/score/cpu/h8300/rtems/score/cpu.h
index 77156ec..621b3f1 100644
--- a/cpukit/score/cpu/h8300/rtems/score/cpu.h
+++ b/cpukit/score/cpu/h8300/rtems/score/cpu.h
@@ -858,7 +858,7 @@ uint32_t   _CPU_ISR_Get_level( void );
 
 /*
  *  This routine sets _output to the bit number of the first bit
- *  set in _value.  _value is of CPU dependent type Priority_bit_map_Control.
+ *  set in _value.  _value is of CPU dependent type Priority_bit_map_Word.
  *  This type may be either 16 or 32 bits wide although only the 16
  *  least significant bits will be used.
  *
diff --git a/cpukit/score/cpu/h8300/rtems/score/types.h b/cpukit/score/cpu/h8300/rtems/score/types.h
index 1e71b7e..7ac2b18 100644
--- a/cpukit/score/cpu/h8300/rtems/score/types.h
+++ b/cpukit/score/cpu/h8300/rtems/score/types.h
@@ -31,7 +31,7 @@ extern "C" {
  *  This section defines the basic types for this processor.
  */
 
-typedef uint16_t     Priority_bit_map_Control;
+typedef uint16_t     Priority_bit_map_Word;
 typedef void h8300_isr;
 typedef void ( *h8300_isr_entry )( void );
 
diff --git a/cpukit/score/cpu/i386/rtems/score/types.h b/cpukit/score/cpu/i386/rtems/score/types.h
index 170e8d8..72461fb 100644
--- a/cpukit/score/cpu/i386/rtems/score/types.h
+++ b/cpukit/score/cpu/i386/rtems/score/types.h
@@ -31,7 +31,7 @@ extern "C" {
  *  This section defines the basic types for this processor.
  */
 
-typedef uint16_t Priority_bit_map_Control;
+typedef uint16_t Priority_bit_map_Word;
 typedef void i386_isr;
 typedef i386_isr ( *i386_isr_entry )( void );
 
diff --git a/cpukit/score/cpu/lm32/rtems/score/cpu.h b/cpukit/score/cpu/lm32/rtems/score/cpu.h
index 3956c70..8e03245 100644
--- a/cpukit/score/cpu/lm32/rtems/score/cpu.h
+++ b/cpukit/score/cpu/lm32/rtems/score/cpu.h
@@ -950,7 +950,7 @@ extern char _gp[];
 /**
  * This routine sets @a _output to the bit number of the first bit
  * set in @a _value.  @a _value is of CPU dependent type
- * @a Priority_bit_map_Control.  This type may be either 16 or 32 bits
+ * @a Priority_bit_map_Word.  This type may be either 16 or 32 bits
  * wide although only the 16 least significant bits will be used.
  *
  * There are a number of variables in using a "find first bit" type
diff --git a/cpukit/score/cpu/lm32/rtems/score/types.h b/cpukit/score/cpu/lm32/rtems/score/types.h
index 4127ad4..ab9dcbd 100644
--- a/cpukit/score/cpu/lm32/rtems/score/types.h
+++ b/cpukit/score/cpu/lm32/rtems/score/types.h
@@ -35,7 +35,7 @@ extern "C" {
  */
 
 /** This defines the type for a priority bit map entry. */
-typedef uint16_t Priority_bit_map_Control;
+typedef uint16_t Priority_bit_map_Word;
 
 #ifdef __cplusplus
 }
diff --git a/cpukit/score/cpu/m32c/rtems/score/cpu.h b/cpukit/score/cpu/m32c/rtems/score/cpu.h
index 338ed57..fa31d74 100644
--- a/cpukit/score/cpu/m32c/rtems/score/cpu.h
+++ b/cpukit/score/cpu/m32c/rtems/score/cpu.h
@@ -941,7 +941,7 @@ void _CPU_Context_Restart_self(
 /**
  * This routine sets @a _output to the bit number of the first bit
  * set in @a _value.  @a _value is of CPU dependent type
- * @a Priority_bit_map_Control.  This type may be either 16 or 32 bits
+ * @a Priority_bit_map_Word.  This type may be either 16 or 32 bits
  * wide although only the 16 least significant bits will be used.
  *
  * There are a number of variables in using a "find first bit" type
diff --git a/cpukit/score/cpu/m32c/rtems/score/types.h b/cpukit/score/cpu/m32c/rtems/score/types.h
index 9db85e9..5c476c6 100644
--- a/cpukit/score/cpu/m32c/rtems/score/types.h
+++ b/cpukit/score/cpu/m32c/rtems/score/types.h
@@ -32,7 +32,7 @@ extern "C" {
  */
 
 /** This defines the type for a priority bit map entry. */
-typedef uint16_t Priority_bit_map_Control;
+typedef uint16_t Priority_bit_map_Word;
 
 /** This defines the return type for an ISR entry point. */
 typedef void m32c_isr;
diff --git a/cpukit/score/cpu/m32r/rtems/score/cpu.h b/cpukit/score/cpu/m32r/rtems/score/cpu.h
index 8902bdf..bf1d3fc 100644
--- a/cpukit/score/cpu/m32r/rtems/score/cpu.h
+++ b/cpukit/score/cpu/m32r/rtems/score/cpu.h
@@ -959,7 +959,7 @@ void _CPU_Context_Restart_self(
 /**
  * This routine sets @a _output to the bit number of the first bit
  * set in @a _value.  @a _value is of CPU dependent type
- * @a Priority_bit_map_Control.  This type may be either 16 or 32 bits
+ * @a Priority_bit_map_Word.  This type may be either 16 or 32 bits
  * wide although only the 16 least significant bits will be used.
  *
  * There are a number of variables in using a "find first bit" type
diff --git a/cpukit/score/cpu/m32r/rtems/score/types.h b/cpukit/score/cpu/m32r/rtems/score/types.h
index b127fcd..2439fb5 100644
--- a/cpukit/score/cpu/m32r/rtems/score/types.h
+++ b/cpukit/score/cpu/m32r/rtems/score/types.h
@@ -32,7 +32,7 @@ extern "C" {
  */
 
 /** This defines the type for a priority bit map entry. */
-typedef uint16_t Priority_bit_map_Control;
+typedef uint16_t Priority_bit_map_Word;
 
 /** This defines the return type for an ISR entry point. */
 typedef void m32r_isr;
diff --git a/cpukit/score/cpu/m68k/rtems/score/types.h b/cpukit/score/cpu/m68k/rtems/score/types.h
index b1ec89a..b5af1c8 100644
--- a/cpukit/score/cpu/m68k/rtems/score/types.h
+++ b/cpukit/score/cpu/m68k/rtems/score/types.h
@@ -31,7 +31,7 @@ extern "C" {
  *  This section defines the basic types for this processor.
  */
 
-typedef uint16_t     Priority_bit_map_Control;
+typedef uint16_t     Priority_bit_map_Word;
 
 #ifdef __cplusplus
 }
diff --git a/cpukit/score/cpu/mips/rtems/score/cpu.h b/cpukit/score/cpu/mips/rtems/score/cpu.h
index c4873fb..b871969 100644
--- a/cpukit/score/cpu/mips/rtems/score/cpu.h
+++ b/cpukit/score/cpu/mips/rtems/score/cpu.h
@@ -937,7 +937,7 @@ extern void mips_break( int error );
 
 /*
  *  This routine sets _output to the bit number of the first bit
- *  set in _value.  _value is of CPU dependent type Priority_bit_map_Control.
+ *  set in _value.  _value is of CPU dependent type Priority_bit_map_Word.
  *  This type may be either 16 or 32 bits wide although only the 16
  *  least significant bits will be used.
  *
diff --git a/cpukit/score/cpu/mips/rtems/score/types.h b/cpukit/score/cpu/mips/rtems/score/types.h
index 2f25474..3f9429b 100644
--- a/cpukit/score/cpu/mips/rtems/score/types.h
+++ b/cpukit/score/cpu/mips/rtems/score/types.h
@@ -40,7 +40,7 @@ extern "C" {
  *  This section defines the basic types for this processor.
  */
 
-typedef uint16_t     Priority_bit_map_Control;
+typedef uint16_t     Priority_bit_map_Word;
 typedef void mips_isr;
 typedef void ( *mips_isr_entry )( void );
 
diff --git a/cpukit/score/cpu/moxie/rtems/score/types.h b/cpukit/score/cpu/moxie/rtems/score/types.h
index 009054d..9cabd15 100644
--- a/cpukit/score/cpu/moxie/rtems/score/types.h
+++ b/cpukit/score/cpu/moxie/rtems/score/types.h
@@ -34,7 +34,7 @@ extern "C" {
 /*
  *  This section defines the basic types for this processor.
  */
-typedef uint16_t     Priority_bit_map_Control;
+typedef uint16_t     Priority_bit_map_Word;
 typedef void moxie_isr;
 typedef void ( *moxie_isr_entry )( void );
 
diff --git a/cpukit/score/cpu/nios2/rtems/score/types.h b/cpukit/score/cpu/nios2/rtems/score/types.h
index 166f552..d81d19a 100644
--- a/cpukit/score/cpu/nios2/rtems/score/types.h
+++ b/cpukit/score/cpu/nios2/rtems/score/types.h
@@ -31,7 +31,7 @@ extern "C" {
  *  This section defines the basic types for this processor.
  */
 
-typedef uint16_t Priority_bit_map_Control;
+typedef uint16_t Priority_bit_map_Word;
 typedef void nios2_isr;
 typedef void ( *nios2_isr_entry )( void );
 
diff --git a/cpukit/score/cpu/no_cpu/rtems/score/cpu.h b/cpukit/score/cpu/no_cpu/rtems/score/cpu.h
index aa1eb74..0b6c4da 100644
--- a/cpukit/score/cpu/no_cpu/rtems/score/cpu.h
+++ b/cpukit/score/cpu/no_cpu/rtems/score/cpu.h
@@ -1059,7 +1059,7 @@ uint32_t   _CPU_ISR_Get_level( void );
 /**
  * This routine sets @a _output to the bit number of the first bit
  * set in @a _value.  @a _value is of CPU dependent type
- * @a Priority_bit_map_Control.  This type may be either 16 or 32 bits
+ * @a Priority_bit_map_Word.  This type may be either 16 or 32 bits
  * wide although only the 16 least significant bits will be used.
  *
  * There are a number of variables in using a "find first bit" type
diff --git a/cpukit/score/cpu/no_cpu/rtems/score/types.h b/cpukit/score/cpu/no_cpu/rtems/score/types.h
index 667e4ec..edf9277 100644
--- a/cpukit/score/cpu/no_cpu/rtems/score/types.h
+++ b/cpukit/score/cpu/no_cpu/rtems/score/types.h
@@ -32,7 +32,7 @@ extern "C" {
  */
 
 /** This defines the type for a priority bit map entry. */
-typedef uint16_t Priority_bit_map_Control;
+typedef uint16_t Priority_bit_map_Word;
 
 #ifdef __cplusplus
 }
diff --git a/cpukit/score/cpu/powerpc/rtems/score/cpu.h b/cpukit/score/cpu/powerpc/rtems/score/cpu.h
index 18f825c..a7cad2e 100644
--- a/cpukit/score/cpu/powerpc/rtems/score/cpu.h
+++ b/cpukit/score/cpu/powerpc/rtems/score/cpu.h
@@ -878,7 +878,7 @@ void _CPU_Context_Initialize(
 
 /*
  *  This routine sets _output to the bit number of the first bit
- *  set in _value.  _value is of CPU dependent type Priority_bit_map_Control.
+ *  set in _value.  _value is of CPU dependent type Priority_bit_map_Word.
  *  This type may be either 16 or 32 bits wide although only the 16
  *  least significant bits will be used.
  *
diff --git a/cpukit/score/cpu/powerpc/rtems/score/types.h b/cpukit/score/cpu/powerpc/rtems/score/types.h
index 3b897ca..0679f40 100644
--- a/cpukit/score/cpu/powerpc/rtems/score/types.h
+++ b/cpukit/score/cpu/powerpc/rtems/score/types.h
@@ -47,7 +47,7 @@ extern "C" {
 /*
  *  This section defines the basic types for this processor.
  */
-typedef uint32_t     Priority_bit_map_Control;
+typedef uint32_t     Priority_bit_map_Word;
 typedef void ppc_isr;
 
 #ifdef __cplusplus
diff --git a/cpukit/score/cpu/sh/rtems/score/cpu.h b/cpukit/score/cpu/sh/rtems/score/cpu.h
index e7a43f9..cb89953 100644
--- a/cpukit/score/cpu/sh/rtems/score/cpu.h
+++ b/cpukit/score/cpu/sh/rtems/score/cpu.h
@@ -691,7 +691,7 @@ SCORE_EXTERN void _CPU_Context_Initialize(
 
 /*
  *  This routine sets _output to the bit number of the first bit
- *  set in _value.  _value is of CPU dependent type Priority_bit_map_Control.
+ *  set in _value.  _value is of CPU dependent type Priority_bit_map_Word.
  *  This type may be either 16 or 32 bits wide although only the 16
  *  least significant bits will be used.
  *
diff --git a/cpukit/score/cpu/sh/rtems/score/types.h b/cpukit/score/cpu/sh/rtems/score/types.h
index 5f9699e..0734d1b 100644
--- a/cpukit/score/cpu/sh/rtems/score/types.h
+++ b/cpukit/score/cpu/sh/rtems/score/types.h
@@ -41,7 +41,7 @@ extern "C" {
  *  This section defines the basic types for this processor.
  */
 
-typedef uint16_t     Priority_bit_map_Control;
+typedef uint16_t     Priority_bit_map_Word;
 
 typedef void sh_isr;
 typedef void ( *sh_isr_entry )( void );
diff --git a/cpukit/score/cpu/sparc/rtems/score/types.h b/cpukit/score/cpu/sparc/rtems/score/types.h
index cfa8f73..71a401c 100644
--- a/cpukit/score/cpu/sparc/rtems/score/types.h
+++ b/cpukit/score/cpu/sparc/rtems/score/types.h
@@ -34,7 +34,7 @@ extern "C" {
  * for using 16-bit variables.  With no overriding architectural factors,
  * just using a uint16_t.
  */
-typedef uint16_t Priority_bit_map_Control;
+typedef uint16_t Priority_bit_map_Word;
 
 /**
  * @brief SPARC ISR handler return type.
diff --git a/cpukit/score/cpu/sparc64/rtems/score/types.h b/cpukit/score/cpu/sparc64/rtems/score/types.h
index 153f66f..6263b56 100644
--- a/cpukit/score/cpu/sparc64/rtems/score/types.h
+++ b/cpukit/score/cpu/sparc64/rtems/score/types.h
@@ -31,7 +31,7 @@ extern "C" {
  *  This section defines the basic types for this processor.
  */
 
-typedef uint16_t         Priority_bit_map_Control;
+typedef uint16_t         Priority_bit_map_Word;
 typedef void sparc_isr;
 typedef void ( *sparc_isr_entry )( void );
 
diff --git a/cpukit/score/cpu/v850/rtems/score/cpu.h b/cpukit/score/cpu/v850/rtems/score/cpu.h
index b348021..35ed6e6 100644
--- a/cpukit/score/cpu/v850/rtems/score/cpu.h
+++ b/cpukit/score/cpu/v850/rtems/score/cpu.h
@@ -935,7 +935,7 @@ void _CPU_Context_Initialize(
 /**
  * This routine sets @a _output to the bit number of the first bit
  * set in @a _value.  @a _value is of CPU dependent type
- * @a Priority_bit_map_Control.  This type may be either 16 or 32 bits
+ * @a Priority_bit_map_Word.  This type may be either 16 or 32 bits
  * wide although only the 16 least significant bits will be used.
  *
  * There are a number of variables in using a "find first bit" type
diff --git a/cpukit/score/cpu/v850/rtems/score/types.h b/cpukit/score/cpu/v850/rtems/score/types.h
index 1d72a7b..7645f5b 100644
--- a/cpukit/score/cpu/v850/rtems/score/types.h
+++ b/cpukit/score/cpu/v850/rtems/score/types.h
@@ -32,7 +32,7 @@ extern "C" {
  */
 
 /** This defines the type for a priority bit map entry. */
-typedef uint16_t Priority_bit_map_Control;
+typedef uint16_t Priority_bit_map_Word;
 
 #ifdef __cplusplus
 }
diff --git a/cpukit/score/src/prioritybitmap.c b/cpukit/score/src/prioritybitmap.c
index 1fda42f..d05ede1 100644
--- a/cpukit/score/src/prioritybitmap.c
+++ b/cpukit/score/src/prioritybitmap.c
@@ -21,7 +21,7 @@
 
 #include <rtems/score/prioritybitmapimpl.h>
 
-Priority_bit_map_Control          _Priority_Bit_map[16] CPU_STRUCTURE_ALIGNMENT;
+Priority_bit_map_Word          _Priority_Bit_map[16] CPU_STRUCTURE_ALIGNMENT;
 
 /* Instantiate any global variables needed by the priority scheduler */
-volatile Priority_bit_map_Control _Priority_Major_bit_map;
+volatile Priority_bit_map_Word _Priority_Major_bit_map;
diff --git a/cpukit/score/include/rtems/score/prioritybitmap.h b/cpukit/score/include/rtems/score/prioritybitmap.h
index ec8a10b..2ef78be 100644
--- a/cpukit/score/include/rtems/score/prioritybitmap.h
+++ b/cpukit/score/include/rtems/score/prioritybitmap.h
@@ -33,7 +33,7 @@ extern "C" {
 /**@{*/
 
 /*
  *  The definition of the Priority_bit_map_Control type is CPU dependent.
  *
  */
 
@@ -43,15 +43,15 @@ extern "C" {
  */
 typedef struct {
   /** This is the address of minor bit map slot. */
-  Priority_bit_map_Control *minor;
+  Priority_bit_map_Word *minor;
   /** This is the priority bit map ready mask. */
-  Priority_bit_map_Control  ready_major;
+  Priority_bit_map_Word  ready_major;
   /** This is the priority bit map ready mask. */
-  Priority_bit_map_Control  ready_minor;
+  Priority_bit_map_Word  ready_minor;
   /** This is the priority bit map block mask. */
-  Priority_bit_map_Control  block_major;
+  Priority_bit_map_Word  block_major;
   /** This is the priority bit map block mask. */
-  Priority_bit_map_Control  block_minor;
+  Priority_bit_map_Word  block_minor;
 } Priority_bit_map_Information;
 
 /**@}*/
@@ -33,7 +33,7 @@ extern "C" {
 
 /*
- *  The definition of the Priority_bit_map_Control type is CPU dependent.
+ *  The definition of the Priority_bit_map_Word type is CPU dependent.
  *
  */
diff --git a/cpukit/score/include/rtems/score/prioritybitmapimpl.h b/cpukit/score/include/rtems/score/prioritybitmapimpl.h
index 694ac9e..df65fb4 100644
--- a/cpukit/score/include/rtems/score/prioritybitmapimpl.h
+++ b/cpukit/score/include/rtems/score/prioritybitmapimpl.h
@@ -32,7 +32,7 @@ extern "C" {
 /**@{**/
 
 /*
  * The Priority_bit_map_Control variables are instantiated only
  * if using the bit map handler.
  */
 
@@ -40,7 +40,7 @@ extern "C" {
  *  Each sixteen bit entry in this array is associated with one of
  *  the sixteen entries in the Priority Bit map.
  */
-extern volatile Priority_bit_map_Control _Priority_Major_bit_map;
+extern volatile Priority_bit_map_Word _Priority_Major_bit_map;
 
 /** Each bit in the Priority Bitmap indicates whether or not there are
  *  threads ready at a particular priority.  The mapping of
@@ -48,7 +48,7 @@ extern volatile Priority_bit_map_Control _Priority_Major_bit_map;
  *  dependent as is the value of each bit used to indicate that
  *  threads are ready at that priority.
  */
-extern Priority_bit_map_Control
+extern Priority_bit_map_Word
                _Priority_Bit_map[16] CPU_STRUCTURE_ALIGNMENT;
 
 #if ( CPU_USE_GENERIC_BITFIELD_DATA == TRUE )
@@ -91,9 +91,9 @@ extern const unsigned char __log2table[256];
     register const unsigned char *__p = __log2table; \
     \
     if ( __value < 0x100 ) \
-      (_bit_number) = (Priority_bit_map_Control)( __p[ __value ] + 8 );  \
+      (_bit_number) = (Priority_bit_map_Word)( __p[ __value ] + 8 );  \
     else \
-      (_bit_number) = (Priority_bit_map_Control)( __p[ __value >> 8 ] ); \
+      (_bit_number) = (Priority_bit_map_Word)( __p[ __value >> 8 ] ); \
   }
 #endif
 
@@ -130,22 +130,22 @@ extern const unsigned char __log2table[256];
  * This function returns the major portion of the_priority.
  */
 
-RTEMS_INLINE_ROUTINE Priority_bit_map_Control   _Priority_Major (
+RTEMS_INLINE_ROUTINE Priority_bit_map_Word   _Priority_Major (
   Priority_Control the_priority
 )
 {
-  return (Priority_bit_map_Control)( the_priority / 16 );
+  return (Priority_bit_map_Word)( the_priority / 16 );
 }
 
 /**
  * This function returns the minor portion of the_priority.
  */
 
-RTEMS_INLINE_ROUTINE Priority_bit_map_Control   _Priority_Minor (
+RTEMS_INLINE_ROUTINE Priority_bit_map_Word   _Priority_Minor (
   Priority_Control the_priority
 )
 {
-  return (Priority_bit_map_Control)( the_priority % 16 );
+  return (Priority_bit_map_Word)( the_priority % 16 );
 }
 
 #if ( CPU_USE_GENERIC_BITFIELD_CODE == TRUE )
@@ -155,22 +155,22 @@ RTEMS_INLINE_ROUTINE Priority_bit_map_Control   _Priority_Minor (
  * number passed to it.
  */
 
-RTEMS_INLINE_ROUTINE Priority_bit_map_Control   _Priority_Mask (
+RTEMS_INLINE_ROUTINE Priority_bit_map_Word   _Priority_Mask (
   uint32_t   bit_number
 )
 {
-  return (Priority_bit_map_Control)(0x8000u >> bit_number);
+  return (Priority_bit_map_Word)(0x8000u >> bit_number);
 }
 
 /**
  * This function returns the mask bit inverted.
  */
 
-RTEMS_INLINE_ROUTINE Priority_bit_map_Control   _Priority_Mask_invert (
+RTEMS_INLINE_ROUTINE Priority_bit_map_Word   _Priority_Mask_invert (
   uint32_t   mask
 )
 {
-  return (Priority_bit_map_Control)(~mask);
+  return (Priority_bit_map_Word)(~mask);
 }
 
 /**
@@ -195,7 +195,7 @@ RTEMS_INLINE_ROUTINE uint32_t   _Priority_Bits_index (
 /**
  *  This is the minor bit map.
  */
-extern Priority_bit_map_Control _Priority_Bit_map[16] CPU_STRUCTURE_ALIGNMENT;
+extern Priority_bit_map_Word _Priority_Bit_map[16] CPU_STRUCTURE_ALIGNMENT;
 
 /**
  * This routine uses the_priority_map to update the priority
@@ -232,8 +232,8 @@ RTEMS_INLINE_ROUTINE void _Priority_bit_map_Remove (
 
 RTEMS_INLINE_ROUTINE Priority_Control _Priority_bit_map_Get_highest( void )
 {
-  Priority_bit_map_Control minor;
-  Priority_bit_map_Control major;
+  Priority_bit_map_Word minor;
+  Priority_bit_map_Word major;
 
   _Bitfield_Find_first_bit( _Priority_Major_bit_map, major );
   _Bitfield_Find_first_bit( _Priority_Bit_map[major], minor );
@@ -258,9 +258,9 @@ RTEMS_INLINE_ROUTINE void _Priority_bit_map_Initialize_information(
   Priority_Control      new_priority
 )
 {
-  Priority_bit_map_Control major;
-  Priority_bit_map_Control minor;
-  Priority_bit_map_Control mask;
+  Priority_bit_map_Word major;
+  Priority_bit_map_Word minor;
+  Priority_bit_map_Word mask;
 
   major = _Priority_Major( new_priority );
   minor = _Priority_Minor( new_priority );
@@ -271,12 +271,12 @@ RTEMS_INLINE_ROUTINE void _Priority_bit_map_Initialize_information(
   mask = _Priority_Mask( major );
   the_priority_map->ready_major = mask;
   /* Add _Priority_Mask_invert to non-generic bitfield then change this code. */
-  the_priority_map->block_major = (Priority_bit_map_Control)(~((uint32_t)mask));
+  the_priority_map->block_major = (Priority_bit_map_Word)(~((uint32_t)mask));
 
   mask = _Priority_Mask( minor );
   the_priority_map->ready_minor = mask;
   /* Add _Priority_Mask_invert to non-generic bitfield then change this code. */
-  the_priority_map->block_minor = (Priority_bit_map_Control)(~((uint32_t)mask));
+  the_priority_map->block_minor = (Priority_bit_map_Word)(~((uint32_t)mask));
 }
 
 /** @} */
@@ -32,7 +32,7 @@ extern "C" {
 
 /*
- * The Priority_bit_map_Control variables are instantiated only
+ * The Priority_bit_map_Word variables are instantiated only
  * if using the bit map handler.
  */
-- 
1.7.7




More information about the devel mailing list